# Matiopy

(Transform Python)

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Github: Repo](https://img.shields.io/badge/github-repo-blue?logo=github)](https://github.com/FrigatZero/matiopy)

---

A library for 2D transformations and vector operations

## Install

---

You can install ```Matiopy``` from ```PyPI```

```bash
pip install matiopy
```